aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/gpu/GrClipMaskManager.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gpu/GrClipMaskManager.h')
-rw-r--r--src/gpu/GrClipMaskManager.h17
1 files changed, 7 insertions, 10 deletions
diff --git a/src/gpu/GrClipMaskManager.h b/src/gpu/GrClipMaskManager.h
index c3a1b5ee70..0c8484abf1 100644
--- a/src/gpu/GrClipMaskManager.h
+++ b/src/gpu/GrClipMaskManager.h
@@ -167,19 +167,16 @@ enum InitialState {
kAllOut_InitialState,
};
/** This function takes a clip stack and produces a reduced set of SkClipStack::Iter::Clip elements
* in param clips that are equivalent to the full stack. If a finite bound for the area inside the
* clip can be determined resultsAreBounds will be true and resultBounds will be those bounds. When
* the results are bounded it is assumed that the caller will restrict the effect of each operation
* to the bounds or intersect with the bounds as a final step. The initial state of the bounds (or
* the unbounded plane when resultsArBounded is false) before the first element of clips is applied
* is returned via initialState. This function is declared here so that it can be unit-tested. It
* may become a member function of SkClipStack when its interface is determined to be stable.
*/
void GrReduceClipStack(const SkClipStack& stack,
+ const SkRect& queryBounds,
ElementList* result,
- SkRect* resultBounds,
- bool* resultsAreBounded,
InitialState* initialState);
} // namespace GrReducedClip
@@ -167,19 +167,16 @@ enum InitialState {
kAllOut_InitialState,
};
-/** This function takes a clip stack and produces a reduced set of SkClipStack::Iter::Clip elements
- * in param clips that are equivalent to the full stack. If a finite bound for the area inside the
- * clip can be determined resultsAreBounds will be true and resultBounds will be those bounds. When
- * the results are bounded it is assumed that the caller will restrict the effect of each operation
- * to the bounds or intersect with the bounds as a final step. The initial state of the bounds (or
- * the unbounded plane when resultsArBounded is false) before the first element of clips is applied
- * is returned via initialState. This function is declared here so that it can be unit-tested. It
- * may become a member function of SkClipStack when its interface is determined to be stable.
+/**
+ * This function takes a clip stack and a query rectangle and it produces a reduced set of
+ * SkClipStack::Elements that are equivalent to applying the full stack to the rectangle. The
+ * initial state of the query rectangle before the first clip element is applied is returned via
+ * initialState. This function is declared here so that it can be unit-tested. It may become a
+ * member function of SkClipStack when its interface is determined to be stable.
*/
void GrReduceClipStack(const SkClipStack& stack,